CosyncInput

Struct CosyncInput 

pub struct CosyncInput<T: ?Sized>(/* private fields */);
A guarded pointer to create a CosyncInputGuard by get and to queue more tasks by queue

Implementations

Source

impl<T: 'static + ?Sized> CosyncInput<T>

pub fn get(&mut self) -> CosyncInputGuard<'_, T>

Gets the underlying CosyncInputGuard.

Panics

This can panic if you move the CosyncInput out of a closure (with, eg an mspc channel). Do not do that.

pub fn queue<Task, Out>(&self, task: Task) -> CosyncTaskId
where Task: FnOnce(CosyncInput<T>) -> Out + Send + 'static, Out: Future<Output = ()> + Send,

Queues a new task. This goes to the back of queue.

Panics

It is possible for this function to panic if the CosyncInput was somehow moved out of the closure it was created it. This should not be possible.

pub fn create_queue_handle(&self) -> CosyncQueueHandle<T>

Creates a queue handle which can be used to spawn tasks.