pub struct CosyncInput<T: ?Sized>(/* private fields */);Expand description
A guarded pointer to create a CosyncInputGuard by get and to queue more tasks by queue
Implementations
Sourceimpl<T: 'static + ?Sized> CosyncInput<T>
impl<T: 'static + ?Sized> CosyncInput<T>
Sourcepub fn get(&mut self) -> CosyncInputGuard<'_, T>
pub fn get(&mut self) -> CosyncInputGuard<'_, T>
Gets the underlying CosyncInputGuard.
Panics
This can panic if you move the CosyncInput out of a closure (with, eg an mspc channel). Do
not do that.
Sourcepub fn queue<Task, Out>(&self, task: Task) -> CosyncTaskId
pub fn queue<Task, Out>(&self, task: Task) -> CosyncTaskId
Queues a new task. This goes to the back of queue.
Panics
It is possible for this function to panic if the CosyncInput was somehow moved
out of the closure it was created it. This should not be possible.
Sourcepub fn create_queue_handle(&self) -> CosyncQueueHandle<T>
pub fn create_queue_handle(&self) -> CosyncQueueHandle<T>
Creates a queue handle which can be used to spawn tasks.